@@ -21,8 +21,10 @@
  * USA
  */
 
+#include <Python.h>
 #include <glib-object.h>
 
+#include "config.h"
 #include "pyglib.h"
 #include "pyginterface.h"
 #include "pygi-repository.h"
@@ -41,6 +43,13 @@
 #include "pygi-boxed.h"
 #include "pygi-info.h"
 #include "pygi-struct.h"
+#include "pygobject-object.h"
+#include "pygoptioncontext.h"
+#include "pygoptiongroup.h"
+#include "pygspawn.h"
+#include "gobjectmodule.h"
+#include "pygparamspec.h"
+#include "pygpointer.h"
 
 #include <pyglib-python-compat.h>
 
@@ -567,7 +576,7 @@ pyg_channel_read(PyObject* self, PyObject *args, PyObject *kwargs)
     iochannel = pyg_boxed_get (py_iochannel, GIOChannel);
 
     while (status == G_IO_STATUS_NORMAL
-	   && (max_count == -1 || total_read < max_count)) {
+	   && (max_count == -1 || total_read < (gsize)max_count)) {
 	gsize single_read;
 	char* buf;
 	gsize buf_size;
@@ -585,7 +594,7 @@ pyg_channel_read(PyObject* self, PyObject *args, PyObject *kwargs)
 	    if (ret_obj == NULL)
 		goto failure;
 	}
-	else if (buf_size + total_read > PYGLIB_PyBytes_Size(ret_obj)) {
+	else if (buf_size + total_read > (gsize)PYGLIB_PyBytes_Size(ret_obj)) {
 	    if (PYGLIB_PyBytes_Resize(&ret_obj, buf_size + total_read) == -1)
 		goto failure;
 	}
@@ -602,7 +611,7 @@ pyg_channel_read(PyObject* self, PyObject *args, PyObject *kwargs)
 	total_read += single_read;
     }
 	
-    if ( total_read != PYGLIB_PyBytes_Size(ret_obj) ) {
+    if ( total_read != (gsize)PYGLIB_PyBytes_Size(ret_obj) ) {
 	if (PYGLIB_PyBytes_Resize(&ret_obj, total_read) == -1)
 	    goto failure;
     }
@@ -627,6 +636,34 @@ static PyMethodDef _gi_functions[] = {
     { "source_set_callback", (PyCFunction) pyg_source_set_callback, METH_VARARGS },
     { "io_channel_read", (PyCFunction) pyg_channel_read, METH_VARARGS },
     { "require_foreign", (PyCFunction) pygi_require_foreign, METH_VARARGS | METH_KEYWORDS },
+    { "spawn_async",
+      (PyCFunction)pyglib_spawn_async, METH_VARARGS|METH_KEYWORDS,
+      "spawn_async(argv, envp=None, working_directory=None,\n"
+      "            flags=0, child_setup=None, user_data=None,\n"
+      "            standard_input=None, standard_output=None,\n"
+      "            standard_error=None) -> (pid, stdin, stdout, stderr)\n"
+      "\n"
+      "Execute a child program asynchronously within a glib.MainLoop()\n"
+      "See the reference manual for a complete reference.\n" },
+    { "type_name", pyg_type_name, METH_VARARGS },
+    { "type_from_name", pyg_type_from_name, METH_VARARGS },
+    { "type_is_a", pyg_type_is_a, METH_VARARGS },
+    { "type_register", _wrap_pyg_type_register, METH_VARARGS },
+    { "signal_new", pyg_signal_new, METH_VARARGS },
+    { "list_properties",
+      pyg_object_class_list_properties, METH_VARARGS },
+    { "new",
+      (PyCFunction)pyg_object_new, METH_VARARGS|METH_KEYWORDS },
+    { "signal_accumulator_true_handled",
+      (PyCFunction)pyg_signal_accumulator_true_handled, METH_VARARGS },
+    { "add_emission_hook",
+      (PyCFunction)pyg_add_emission_hook, METH_VARARGS },
+    { "_install_metaclass",
+      (PyCFunction)pyg__install_metaclass, METH_O },
+    { "_gvalue_get",
+      (PyCFunction)pyg__gvalue_get, METH_O },
+    { "_gvalue_set",
+      (PyCFunction)pyg__gvalue_set, METH_VARARGS },
     { NULL, NULL, 0 }
 };
 
@@ -637,8 +674,7 @@ static struct PyGI_API CAPI = {
 PYGLIB_MODULE_START(_gi, "_gi")
 {
     PyObject *api;
-    PyObject *_glib_module;
-    PyObject *_gobject_module;
+    PyObject *module_dict = PyModule_GetDict (module);
 
     /* Always enable Python threads since we cannot predict which GI repositories
      * might accept Python callbacks run within non-Python threads or might trigger
@@ -647,29 +683,6 @@ PYGLIB_MODULE_START(_gi, "_gi")
      */
     PyEval_InitThreads ();
 
-    _glib_module = pyglib__glib_module_create ();
-    if (_glib_module == NULL) {
-        return PYGLIB_MODULE_ERROR_RETURN;
-    }
-    /* In Python 2.x, pyglib_..._module_create returns a borrowed reference and
-     * PyModule_AddObject steals a reference. Ensure we don't share a reference
-     * between sys.modules and gi._gi._glib by incrementing the ref count here.
-     * Note that we don't add this to the PYGLIB_MODULE_START macro because that
-     * would cause a leak for the main module gi._gi */
-    if (PY_MAJOR_VERSION < 3) {
-        Py_INCREF (_glib_module);
-    }
-    PyModule_AddObject (module, "_glib", _glib_module);
-    PyModule_AddStringConstant(module, "__package__", "gi._gi");
-
-    _gobject_module = pyglib__gobject_module_create ();
-    if (_gobject_module == NULL) {
-        return PYGLIB_MODULE_ERROR_RETURN;
-    }
-    if (PY_MAJOR_VERSION < 3) {
-        Py_INCREF (_gobject_module);
-    }
-    PyModule_AddObject (module, "_gobject", _gobject_module);
     PyModule_AddStringConstant(module, "__package__", "gi._gi");
 
     pygi_foreign_init ();
@@ -681,6 +694,24 @@ PYGLIB_MODULE_START(_gi, "_gi")
     _pygi_ccallback_register_types (module);
     pygi_resulttuple_register_types (module);
 
+    pyglib_spawn_register_types (module_dict);
+    pyglib_option_context_register_types (module_dict);
+    pyglib_option_group_register_types (module_dict);
+
+    pygobject_register_api (module_dict);
+    pygobject_register_constants (module);
+    pygobject_register_features (module_dict);
+    pygobject_register_version_tuples (module_dict);
+    pygobject_register_warnings (module_dict);
+    pygobject_type_register_types (module_dict);
+    pygobject_object_register_types (module_dict);
+    pygobject_interface_register_types (module_dict);
+    pygobject_paramspec_register_types (module_dict);
+    pygobject_boxed_register_types (module_dict);
+    pygobject_pointer_register_types (module_dict);
+    pygobject_enum_register_types (module_dict);
+    pygobject_flags_register_types (module_dict);
+
     PyGIWarning = PyErr_NewException ("gi.PyGIWarning", PyExc_Warning, NULL);
 
     /* Use RuntimeWarning as the base class of PyGIDeprecationWarning
