@@ -16,8 +16,10 @@
  * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "pygi-private.h"
+#include "pygi-signal-closure.h"
 #include "pygi-value.h"
+#include "pygi-argument.h"
+#include "pygi-boxed.h"
 
 static GISignalInfo *
 _pygi_lookup_signal_from_g_type (GType g_type,
@@ -86,6 +88,7 @@ pygi_signal_closure_marshal(GClosure *closure,
 
     signal_info = ((PyGISignalClosure *)closure)->signal_info;
     n_sig_info_args = g_callable_info_get_n_args(signal_info);
+    g_assert_cmpint (n_sig_info_args, >=, 0);
     /* the first argument to a signal callback is instance,
        but instance is not counted in the introspection data */
     sig_info_highest_arg = n_sig_info_args + 1;
@@ -108,7 +111,7 @@ pygi_signal_closure_marshal(GClosure *closure,
             }
             PyTuple_SetItem(params, i, item);
 
-        } else if (i < sig_info_highest_arg) {
+        } else if (i < (guint)sig_info_highest_arg) {
             GIArgInfo arg_info;
             GITypeInfo type_info;
             GITypeTag type_tag;
@@ -179,6 +182,7 @@ pygi_signal_closure_marshal(GClosure *closure,
             }
 
             if (item == NULL) {
+                PyErr_Print ();
                 goto out;
             }
             PyTuple_SetItem(params, i, item);
