@@ -112,7 +112,7 @@ pygobject_data_free(PyGObjectData *data)
 
     if (Py_IsInitialized()) {
 	state_saved = TRUE;
-	state = pyglib_gil_state_ensure();
+	state = PyGILState_Ensure();
 	Py_DECREF(data->type);
 	/* We cannot use Py_BEGIN_ALLOW_THREADS here because this is inside
 	 * a branch. */
@@ -140,7 +140,7 @@ pygobject_data_free(PyGObjectData *data)
 
     if (state_saved && Py_IsInitialized ()) {
 	Py_BLOCK_THREADS; /* Restores _save */
-	pyglib_gil_state_release(state);
+	PyGILState_Release(state);
     }
 }
 
@@ -206,7 +206,7 @@ typedef struct {
     guint index;
 } PyGPropsIter;
 
-PYGLIB_DEFINE_TYPE("gi._gobject.GPropsIter", PyGPropsIter_Type, PyGPropsIter);
+PYGLIB_DEFINE_TYPE("gi._gi.GPropsIter", PyGPropsIter_Type, PyGPropsIter);
 
 static void
 pyg_props_iter_dealloc(PyGPropsIter *self)
@@ -351,7 +351,7 @@ set_property_from_pspec(GObject *obj,
     return TRUE;
 }
 
-PYGLIB_DEFINE_TYPE("gi._gobject.GProps", PyGProps_Type, PyGProps);
+PYGLIB_DEFINE_TYPE("gi._gi.GProps", PyGProps_Type, PyGProps);
 
 static int
 PyGProps_setattro(PyGProps *self, PyObject *attr, PyObject *pvalue)
@@ -477,7 +477,7 @@ static PySequenceMethods _PyGProps_as_sequence = {
     0
 };
 
-PYGLIB_DEFINE_TYPE("gi._gobject.GPropsDescr", PyGPropsDescr_Type, PyObject);
+PYGLIB_DEFINE_TYPE("gi._gi.GPropsDescr", PyGPropsDescr_Type, PyObject);
 
 static PyObject *
 pyg_props_descr_descr_get(PyObject *self, PyObject *obj, PyObject *type)
@@ -606,7 +606,7 @@ pyg_toggle_notify (gpointer data, GObject *object, gboolean is_last_ref)
     PyGObject *self;
     PyGILState_STATE state;
 
-    state = pyglib_gil_state_ensure();
+    state = PyGILState_Ensure();
 
     /* Avoid thread safety problems by using qdata for wrapper retrieval
      * instead of the user data argument.
@@ -620,7 +620,7 @@ pyg_toggle_notify (gpointer data, GObject *object, gboolean is_last_ref)
             Py_INCREF(self);
     }
 
-    pyglib_gil_state_release(state);
+    PyGILState_Release(state);
 }
 
   /* Called when the inst_dict is first created; switches the 
@@ -701,7 +701,7 @@ pyg_type_get_bases(GType gtype)
     guint n_interfaces;
     PyTypeObject *py_parent_type, *py_interface_type;
     PyObject *bases;
-    int i;
+    guint i;
     
     if (G_UNLIKELY(gtype == G_TYPE_OBJECT))
         return NULL;
@@ -747,7 +747,7 @@ pygobject_new_with_interfaces(GType gtype)
     PyTypeObject *py_parent_type;
     PyObject *bases;
 
-    state = pyglib_gil_state_ensure();
+    state = PyGILState_Ensure();
 
     bases = pyg_type_get_bases(gtype);
     py_parent_type = (PyTypeObject *) PyTuple_GetItem(bases, 0);
@@ -772,7 +772,7 @@ pygobject_new_with_interfaces(GType gtype)
 
     if (type == NULL) {
 	PyErr_Print();
-        pyglib_gil_state_release(state);
+        PyGILState_Release(state);
 	return NULL;
     }
 
@@ -797,7 +797,7 @@ pygobject_new_with_interfaces(GType gtype)
 
     if (PyType_Ready(type) < 0) {
 	g_warning ("couldn't make the type `%s' ready", type->tp_name);
-        pyglib_gil_state_release(state);
+        PyGILState_Release(state);
 	return NULL;
     }
 
@@ -805,7 +805,7 @@ pygobject_new_with_interfaces(GType gtype)
     Py_INCREF(type);
     g_type_set_qdata(gtype, pygobject_class_key, type);
 
-    pyglib_gil_state_release(state);
+    PyGILState_Release(state);
 
     return type;
 }
@@ -847,7 +847,7 @@ pygobject_inherit_slots(PyTypeObject *type, PyObject *bases, gboolean check_for_
                                   offsetof(PyTypeObject, tp_repr),
                                   offsetof(PyTypeObject, tp_str),
                                   offsetof(PyTypeObject, tp_print) };
-    int i;
+    gsize i;
 
     /* Happens when registering gobject.GObject itself, at least. */
     if (!bases)
@@ -913,6 +913,8 @@ pygobject_find_slot_for(PyTypeObject *type, PyObject *bases, int slot_offset,
  * or interface has been registered for the given GType, then a new
  * type will be created.
  *
+ * Does not set an exception when NULL is returned.
+ *
  * Returns: The wrapper class for the GObject or NULL if the
  *          GType has no registered type and a new type couldn't be created
  */
@@ -922,19 +924,22 @@ pygobject_lookup_class(GType gtype)
     PyTypeObject *py_type;
 
     if (gtype == G_TYPE_INTERFACE)
-	return &PyGInterface_Type;
+        return &PyGInterface_Type;
     
     py_type = g_type_get_qdata(gtype, pygobject_class_key);
     if (py_type == NULL) {
-	py_type = g_type_get_qdata(gtype, pyginterface_type_key);
+        py_type = g_type_get_qdata(gtype, pyginterface_type_key);
 
-    if (py_type == NULL)
-        py_type = (PyTypeObject *)pygi_type_import_by_g_type(gtype);
+        if (py_type == NULL) {
+            py_type = (PyTypeObject *)pygi_type_import_by_g_type(gtype);
+            PyErr_Clear ();
+        }
 
-	if (py_type == NULL) {
-	    py_type = pygobject_new_with_interfaces(gtype);
-	    g_type_set_qdata(gtype, pyginterface_type_key, py_type);
-	}
+        if (py_type == NULL) {
+            py_type = pygobject_new_with_interfaces(gtype);
+            PyErr_Clear ();
+            g_type_set_qdata(gtype, pyginterface_type_key, py_type);
+        }
     }
     
     return py_type;
@@ -1067,7 +1072,7 @@ pygobject_watch_closure(PyObject *self, GClosure *closure)
 
 /* -------------- PyGObject behaviour ----------------- */
 
-PYGLIB_DEFINE_TYPE("gi._gobject.GObject", PyGObject_Type, PyGObject);
+PYGLIB_DEFINE_TYPE("gi._gi.GObject", PyGObject_Type, PyGObject);
 
 static void
 pygobject_dealloc(PyGObject *self)
@@ -1115,10 +1120,10 @@ pygobject_richcompare(PyObject *self, PyObject *other, int op)
                                            op);
 }
 
-static long
+static PYGLIB_Py_hash_t
 pygobject_hash(PyGObject *self)
 {
-    return (long)self->obj;
+    return PYGLIB_Py_hash_t_FromVoidPtr (self->obj);
 }
 
 static PyObject *
@@ -1459,10 +1464,10 @@ pygbinding_closure_invalidate(gpointer data, GClosure *closure)
     PyGClosure *pc = (PyGClosure *)closure;
     PyGILState_STATE state;
 
-    state = pyglib_gil_state_ensure();
+    state = PyGILState_Ensure();
     Py_XDECREF(pc->callback);
     Py_XDECREF(pc->extra_args);
-    pyglib_gil_state_release(state);
+    PyGILState_Release(state);
 
     pc->callback = NULL;
     pc->extra_args = NULL;
@@ -1481,7 +1486,7 @@ pygbinding_marshal (GClosure     *closure,
     PyObject *params, *ret;
     GValue *out_value;
 
-    state = pyglib_gil_state_ensure();
+    state = PyGILState_Ensure();
 
     /* construct Python tuple for the parameter values */
     params = PyTuple_New(2);
@@ -1516,7 +1521,7 @@ pygbinding_marshal (GClosure     *closure,
 
 out:
     Py_DECREF(params);
-    pyglib_gil_state_release(state);
+    PyGILState_Release(state);
 }
 
 static GClosure *
@@ -1837,7 +1842,7 @@ pygobject_emit(PyGObject *self, PyObject *args)
 	return NULL;
     }
     g_signal_query(signal_id, &query);
-    if (len != query.n_params + 1) {
+    if ((gsize)len != query.n_params + 1) {
 	gchar buf[128];
 
 	g_snprintf(buf, sizeof(buf),
@@ -1922,7 +1927,7 @@ pygobject_chain_from_overridden(PyGObject *self, PyObject *args)
 	return NULL;
     }
     g_signal_query(signal_id, &query);
-    if (len != query.n_params) {
+    if (len < 0 || (gsize)len != query.n_params) {
 	gchar buf[128];
 
 	g_snprintf(buf, sizeof(buf),
@@ -2201,7 +2206,7 @@ typedef struct {
     gboolean have_floating_ref;
 } PyGObjectWeakRef;
 
-PYGLIB_DEFINE_TYPE("gi._gobject.GObjectWeakRef", PyGObjectWeakRef_Type, PyGObjectWeakRef);
+PYGLIB_DEFINE_TYPE("gi._gi.GObjectWeakRef", PyGObjectWeakRef_Type, PyGObjectWeakRef);
 
 static int
 pygobject_weak_ref_traverse(PyGObjectWeakRef *self, visitproc visit, void *arg)
@@ -2219,7 +2224,7 @@ pygobject_weak_ref_notify(PyGObjectWeakRef *self, GObject *dummy)
     self->obj = NULL;
     if (self->callback) {
         PyObject *retval;
-        PyGILState_STATE state = pyglib_gil_state_ensure();
+        PyGILState_STATE state = PyGILState_Ensure();
         retval = PyObject_Call(self->callback, self->user_data, NULL);
         if (retval) {
             if (retval != Py_None)
@@ -2237,7 +2242,7 @@ pygobject_weak_ref_notify(PyGObjectWeakRef *self, GObject *dummy)
             self->have_floating_ref = FALSE;
             Py_DECREF((PyObject *) self);
         }
-        pyglib_gil_state_release(state);
+        PyGILState_Release(state);
     }
 }
 
@@ -2326,9 +2331,9 @@ pyobject_copy(gpointer boxed)
     PyObject *object = boxed;
     PyGILState_STATE state;
 
-    state = pyglib_gil_state_ensure();
+    state = PyGILState_Ensure();
     Py_INCREF(object);
-    pyglib_gil_state_release(state);
+    PyGILState_Release(state);
     return object;
 }
 
@@ -2338,9 +2343,9 @@ pyobject_free(gpointer boxed)
     PyObject *object = boxed;
     PyGILState_STATE state;
 
-    state = pyglib_gil_state_ensure();
+    state = PyGILState_Ensure();
     Py_DECREF(object);
-    pyglib_gil_state_release(state);
+    PyGILState_Release(state);
 }
 
 void
@@ -2405,7 +2410,7 @@ pygobject_object_register_types(PyObject *d)
     descr = PyObject_New(PyObject, &PyGPropsDescr_Type);
     PyDict_SetItemString(PyGObject_Type.tp_dict, "props", descr);
     PyDict_SetItemString(PyGObject_Type.tp_dict, "__module__",
-                        o=PYGLIB_PyUnicode_FromString("gi._gobject._gobject"));
+                        o=PYGLIB_PyUnicode_FromString("gi._gi"));
     Py_DECREF(o);
 
     /* GPropsIter */
