@@ -8,22 +8,26 @@ import warnings
 from gi.repository import GObject, GLib
 from gi import PyGIDeprecationWarning
 from gi.module import get_introspection_module
-
-import gi
-_gobject = gi._gi._gobject
+from gi import _gi
 
 import testhelper
 
 
 class TestGObjectAPI(unittest.TestCase):
+
+    def test_call_method_uninitialized_instance(self):
+        obj = GObject.Object.__new__(GObject.Object)
+        with self.assertRaisesRegex(RuntimeError, '.*is not initialized'):
+            obj.notify("foo")
+
     def test_gobject_inheritance(self):
         # GObject.Object is a class hierarchy as follows:
         # overrides.Object -> introspection.Object -> static.GObject
         GIObjectModule = get_introspection_module('GObject')
         self.assertTrue(issubclass(GObject.Object, GIObjectModule.Object))
-        self.assertTrue(issubclass(GIObjectModule.Object, _gobject.GObject))
+        self.assertTrue(issubclass(GIObjectModule.Object, _gi.GObject))
 
-        self.assertEqual(_gobject.GObject.__gtype__, GObject.TYPE_OBJECT)
+        self.assertEqual(_gi.GObject.__gtype__, GObject.TYPE_OBJECT)
         self.assertEqual(GIObjectModule.Object.__gtype__, GObject.TYPE_OBJECT)
         self.assertEqual(GObject.Object.__gtype__, GObject.TYPE_OBJECT)
 
