@@ -8,11 +8,7 @@ import gi.overrides
 import gi.module
 import gi.importer
 
-try:
-    from gi.repository import Regress
-    Regress  # pyflakes
-except ImportError:
-    Regress = None
+from gi.repository import Regress
 
 
 class TestOverrides(unittest.TestCase):
@@ -27,7 +23,6 @@ class TestOverrides(unittest.TestCase):
         except TypeError as e:
             self.assertTrue('Can not override a type MyClass' in str(e))
 
-    @unittest.skipUnless(Regress, 'built without cairo support')
     def test_separate_path(self):
         # Regress override is in tests/gi/overrides, separate from gi/overrides
         # https://bugzilla.gnome.org/show_bug.cgi?id=680913
